@@ -493,7 +493,7 @@ class GeneratorTestCase(base.BaseTestCase):
         return self._capture_stream('stdout')
 
     @mock.patch('stevedore.named.NamedExtensionManager')
-    @mock.patch.object(generator, 'LOG')
+    @mock.patch('oslo_config.generator.LOG')
     def test_generate(self, mock_log, named_mgr):
         generator.register_cli_opts(self.conf)
 
